# Generated by Django 2.0.6 on 2018-11-21 08:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('invoicing', '0018_invoice_attachments'),
        # ('invoicing', '0020_auto_20181001_1025'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoice',
            name='related_document',
            field=models.CharField(blank=True, max_length=100),
        ),
    ]
