# Generated by Django 3.1.12 on 2021-06-22 08:55

from django.db import migrations

try:
    # Django 3.1
    from django.db.models import JSONField
except ImportError:
    # older Django
    from django.contrib.postgres.fields import JSONField


class Migration(migrations.Migration):

    dependencies = [
        ('invoicing', '0025_supplier_additional_info_json'),
    ]

    operations = [
        migrations.AlterField(
            model_name='invoice',
            name='attachments',
            field=JSONField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='supplier_additional_info',
            field=JSONField(blank=True, default=None, null=True),
        ),
    ]
