# Generated by Django 2.2.9 on 2020-03-25 11:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('invoicing', '0022_invoice_date_paid'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoice',
            name='related_invoices',
            field=models.ManyToManyField(related_name='_invoice_related_invoices_+', to='invoicing.Invoice'),
        ),
    ]
