# Generated by Django 2.0.3 on 2018-05-31 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('invoicing', '0008_recalculate'),
    ]

    operations = [
        migrations.AlterField(
            model_name='invoice',
            name='vat',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=10, null=True),
        ),
    ]
